==> aliyun-python-sdk-imm-1.6.2.tar.gz: aliyun-python-sdk-imm-1.6.2/aliyunsdkimm/request/v20170906/CompareImageFacesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class CompareImageFacesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'CompareImageFaces','2017-09-06')

	def get_ImageUriB(self):
		return self.get_query_params().get('ImageUriB')

	def set_ImageUriB(self,ImageUriB):
		self.add_query_param('ImageUriB',ImageUriB)

	def get_ImageUriA(self):
		return self.get_query_params().get('ImageUriA')

	def set_ImageUriA(self,ImageUriA):
		self.add_query_param('ImageUriA',ImageUriA)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)

	def get_FaceIdA(self):
		return self.get_query_params().get('FaceIdA')

	def set_FaceIdA(self,FaceIdA):
		self.add_query_param('FaceIdA',FaceIdA)

	def get_FaceIdB(self):
		return self.get_query_params().get('FaceIdB')

	def set_FaceIdB(self,FaceIdB):
		self.add_query_param('FaceIdB',FaceIdB)

==> aliyun-python-sdk-imm-1.9.4.tar.gz: aliyun-python-sdk-imm-1.9.4/aliyunsdkimm/request/v20170906/CompareImageFacesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class CompareImageFacesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'CompareImageFaces','imm')

	def get_ImageUriB(self):
		return self.get_query_params().get('ImageUriB')

	def set_ImageUriB(self,ImageUriB):
		self.add_query_param('ImageUriB',ImageUriB)

	def get_ImageUriA(self):
		return self.get_query_params().get('ImageUriA')

	def set_ImageUriA(self,ImageUriA):
		self.add_query_param('ImageUriA',ImageUriA)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)

	def get_FaceIdA(self):
		return self.get_query_params().get('FaceIdA')

	def set_FaceIdA(self,FaceIdA):
		self.add_query_param('FaceIdA',FaceIdA)

	def get_FaceIdB(self):
		return self.get_query_params().get('FaceIdB')

	def set_FaceIdB(self,FaceIdB):
		self.add_query_param('FaceIdB',FaceIdB)
